==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/ReportcategoryRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Reportcategory;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class ReportcategoryRequest extends EntityRequest<Reportcategory> {

    public ReportcategoryRequest(ContextPath contextPath, Optional<Object> value) {
        super(Reportcategory.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public ReportRequest reportid() {
        return new ReportRequest(contextPath.addSegment("reportid"), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest reportcategory_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("reportcategory_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest reportcategory_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("reportcategory_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SyncerrorCollectionRequest reportCategory_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("ReportCategory_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest reportCategory_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ReportCategory_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TransactioncurrencyRequest transactioncurrencyid() {
        return new TransactioncurrencyRequest(contextPath.addSegment("transactioncurrencyid"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.46-sources.jar: microsoft/dynamics/crm/entity/request/ReportcategoryRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Reportcategory;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class ReportcategoryRequest extends EntityRequest<Reportcategory> {

    public ReportcategoryRequest(ContextPath contextPath, Optional<Object> value) {
        super(Reportcategory.class, contextPath, value);
    }

    public ReportRequest reportid() {
        return new ReportRequest(contextPath.addSegment("reportid"), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest reportcategory_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("reportcategory_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest reportcategory_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("reportcategory_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SyncerrorCollectionRequest reportCategory_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("ReportCategory_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest reportCategory_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ReportCategory_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TransactioncurrencyRequest transactioncurrencyid() {
        return new TransactioncurrencyRequest(contextPath.addSegment("transactioncurrencyid"), Optional.empty());
    }

}
